.. _api_init:

:mod:`pynetdicom`
=================

.. currentmodule:: pynetdicom._globals


Lists of Transfer Syntaxes
--------------------------

.. autosummary::
   :toctree: generated/

   ALL_TRANSFER_SYNTAXES
   DEFAULT_TRANSFER_SYNTAXES


.. currentmodule:: pynetdicom

Variables
---------

.. autosummary::
   :toctree: generated/

   PYNETDICOM_IMPLEMENTATION_UID
   PYNETDICOM_IMPLEMENTATION_VERSION
   PYNETDICOM_UID_PREFIX


Utilities
---------
.. autosummary::
   :toctree: generated/

   debug_logger
